API Reference
=============

datareduction
-------------

.. automodule:: nxs_analysis_tools.datareduction
    :members:

chess
-----

.. automodule:: nxs_analysis_tools.chess
    :members:

fitting
-----

.. automodule:: nxs_analysis_tools.fitting
    :members:

pairdistribution
----------------

.. automodule:: nxs_analysis_tools.pairdistribution
    :members: